import { MidwayError, registerErrorCode } from '@midwayjs/core';

export enum ErrorCode {
  /** 未知错误 */
  UNKNOWN = '-1',
  /** 缺少地址参数 */
  NEED_PARAMS = '-2',
  /** 缺少地址后参数 */
  NEED_QUERY = '-3',
  /** 缺少body参数 */
  NEED_BODY = '-4',
  /** 缺少参数(函数调用中) */
  NEED_ARGS = '-5',
  /** 未找到数据 */
  NOT_FOUND_DATA = '-10',
  /** 业务错误 */
  SERVICE_FAULT = '-100',
  /** 用户没有登录 */
  NOT_LOGIN = '-101',
}

/** 自定义错误枚举数据 */
export const FrameworkErrorEnum = registerErrorCode('ServiceError', ErrorCode);
/**
 * @constructor 自定义异常类
 * @param {string} str 异常说明
 * @param {ErrorCode} errcode 错误代码
 */
export class ServiceError extends MidwayError {
  constructor(str: string, errcode: string = ErrorCode.UNKNOWN) {
    super(str, errcode);
  }
}
